Learn R Programming

ediblecity (version 0.2.2)

SVF: Sky View Factor for City Example

Description

It contains a raster representing the sky view factor for 'city_example', calculated using SAGA algorithm on a digital surface model of 3x3 from a LIDAR dataset.

Arguments

Author

Josep Pueyo-Ros