- x
An 'sf' object with the urban model of your city and a 'land_use' column with categories of urban features.
- SVF
A 'stars' object representing sky view factor. It can be computed, e.g. with SAGA's
Sky View Factor algorithm and then loaded with stars::read_stars().
- green_df
A dataframe of categories that are considered as urban green with two columns. 'land_uses'
with the names of 'land_use' in 'x' to be considered as green; a 'pGreen' column with the percentage of green
of that function. If NULL, categories and values of 'city_land_uses' dataset are considered.
- Qql
A numerical value representing the average solar radiation in W/m2/hour.
- Cair
A numerical value representing the air heat capacity in J.
- Pair
A numerical value representing the air density in kg/m3.
- Tmax
Averaged maximum temperature in ºC.
- Tmin
Averaged minimum temperature in ºC.
- windspeed
Averaged wind speed in m/s.
- return_raster
If TRUE, the raster of UHI values is returned. Otherwise, a summary of raster values is returned.
- verbose
If TRUE, returns a vector with UHI value in each cell.