Learn R Programming

ediblecity (version 0.2.2)

city_example: City example

Description

It contains a urban model as an example to use the package. It is specifically the urban model for Sant Narcís, a neighbourhood of Girona (Catalonia)

Arguments

Author

Josep Pueyo-Ros