Learn R Programming

ediblecity (version 0.2.2)

city_land_uses: City Land Uses

Description

It contains information about the functions belonging to green infrastructure and urban agriculture in the city_example dataset. This information can be used as params in the indicators, in some cases these are already the default values.

Arguments

Author

Josep Pueyo-Ros