# Get the 95% confidence interval
edible_volunteers(city_example, interval = 0.95)
# Get the raw values from the Monte Carlo simulation
# and adjust the number of volunteers by squared meter.
result <- edible_volunteers(city_example, volunteers = c(0.1, 0.2), verbose = TRUE)
result[1:10]
Run the code above in your browser using DataLab