# Get the total values of runoff, rainfall and rain harvested
runoff_prev(city_example)
# Adjust the parameters for rain, maximum distance to harvest rainwater and tank size
runoff_prev(city_example, rain = 160, harvest_dist = 5, tank_size = c(20,30))
Run the code above in your browser using DataLab